<?php
/**
 * Plugin Name: Easy Amazon Wishlist
 * Description: This plugin will display an Amazon Wishlist with your wishlist item links in your sidebar. You can search for the wishlist on all Amazon domains, including Amazon.com, Amazon.de, Amazon.co.jp, etc..  Future features include having more control over the look and feel of how the wishlist displays.  Available in english, deutsch, español, français, italiano, 日本人, 中国的.  For bugs or features contact: hokage@webmasterninjas.com
 * Version: 1.2
 * Author: Stan Quinn
 * Author URI: http://www.webmasterninjas.com
 * License: GPL
 */
add_action('init', 'easy_amazon_wishlist');

function easy_amazon_wishlist() {
    $plugin_dir = basename( dirname( __FILE__ ) );
    load_plugin_textdomain( 'EasyAmazonWishlist', null, $plugin_dir );
    //$listID = get_option('easy-amazon-wishlist-listID');
    //$website = get_option('easy-amazon-wishlist-websites');
    //$listOption = get_option('easy-amazon-wishlist-use-unsorted-list');
    $show_text_link = get_option('easy-amazon-wishlist-show-text-link');
    $show_image = get_option('easy-amazon-wishlist-show-image');
    $show_price = get_option('easy-amazon-wishlist-show-price');
    $show_button = get_option('easy-amazon-wishlist-show-button');
    $button_text = get_option('easy-amazon-wishlist-button-text');
    $text_link_char_limit = get_option('easy-amazon-wishlist-text-link-char-limit');
    $wishlist_json = __DIR__ . 'easy-amazon-wishlist.cache.temp';
    $cache_file = __DIR__ . 'easy-amazon-wishlist.cache';

    if (isset($_POST['action']) && ($_POST['action'] == 'update')) {
        copy($wishlist_json, $cache_file);
        $wishlistArray = json_decode($cache_file);
        return easyAmazonWishlistDisplayPreviewWishlist($wishlistArray, $show_text_link, $show_image, $show_price, $show_button, $button_text, $text_link_char_limit);
    } else {
        if (file_exists($cache_file)) {
            $wishlist_json = file_get_contents($cache_file);
            $wishlistArray = json_decode($wishlist_json);
            return easyAmazonWishlistDisplayPreviewWishlist($wishlistArray, $show_text_link, $show_image, $show_price, $show_button, $button_text, $text_link_char_limit);
        } else {
            return __( 'Please supply a valid', 'EasyAmazonWishlist' ) . ' ' .  __( 'Amazon Wishlist ID', 'EasyAmazonWishlist' ) . '.';
        }
    }
}

if (is_admin() === true) {

    /* Call the html code */
    add_action('admin_menu', 'easy_amazon_wishlist_admin_menu');

    function easy_amazon_wishlist_admin_menu() {
        add_options_page(__( 'Easy Amazon Wishlist', 'EasyAmazonWishlist' ), __( 'Easy Amazon Wishlist', 'EasyAmazonWishlist' ), 'administrator', 'easy-amazon-wishlist', 'easy_amazon_wishlist_admin_page');
    }

    add_action('wp_ajax_eaw_search_action', 'eaw_search_action_callback');
    add_action('wp_ajax_eaw_preview_action', 'eaw_preview_callback');
    add_action('wp_ajax_eaw_pagination_action', 'eaw_pagination_callback');

    function eaw_pagination_callback() {
        $numClicked = isset($_POST['numClicked']) && (strlen($_POST['numClicked']) < 2) ? htmlspecialchars($_POST['numClicked']) : null;
        $search_val = isset($_POST['search_val']) && (strlen($_POST['search_val']) < 40) ? htmlspecialchars($_POST['search_val']) : null;
        $country = isset($_POST['country']) && (strlen($_POST['country']) < 40) ? htmlspecialchars($_POST['country']) : null;
        $content = '';
        $multipageStart = 15*(intval($numClicked) - 1);
        if (isset($numClicked) && isset($search_val) && isset($country)) {
            $localesArray = easy_amazon_wishlist_amazonLocales();
            $locale = $localesArray[$country];
            $websitesArray = easy_amazon_wishlist_amazonWebsites();
            $website = $websitesArray[$country];
            //grab 15 items for that page and return them
            //https://widgets.amazon.com/xml?MarketPlace=US&Name=allison%20collins&multipageCount=15&multipageStart=0&Service=wishlistsearch
            try{
                $content = getWishlists($website, $locale, 'Name', rawurlencode($search_val), '15', $multipageStart);
            } catch (Exception $o) {
                error_log($o);
            }
            ob_clean();
            echo $content;
            die();
        } else {
            ob_clean();
            echo '[]';
            die();
        }
    }

    function eaw_preview_callback() {
        $tPath = null;
        $obj = null;
        $wishlistId = isset($_POST['wishlistId']) && (strlen($_POST['wishlistId']) < 40) ? htmlspecialchars($_POST['wishlistId']) : null;
        $country = isset($_POST['country']) && (strlen($_POST['country']) < 40) ? htmlspecialchars($_POST['country']) : null;
        if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS']) {
            define('PROTOCOL', 'https');
        } else {
            define('PROTOCOL', 'http');
        }
        if (isset($wishlistId) && isset($country)) {
            $localesArray = easy_amazon_wishlist_amazonLocales();
            $locale = $localesArray[$country];
            $websites = easy_amazon_wishlist_amazonWebsites();
            $website = $websites[$country];
            header("Content-Type: text/html; charset=utf-8");
            $tPath = "ws." . $website . base64_decode("L3dpZGdldHMvcT9PcGVyYXRpb249R2V0UmVzdWx0cyZMaXN0SWQ9") . $wishlistId . base64_decode("Jm11bHRpcGFnZVN0YXJ0PTAmSW5zdGFuY2VJZD0wJm11bHRpcGFnZUNvdW50PTEwJlNvcnQ9RGF0ZUFkZGVkJlRlbXBsYXRlSWQ9ODAwNCZTZXJ2aWNlVmVyc2lvbj0yMDA3MDgyMiZNYXJrZXRQbGFjZT0=") . $locale;

            try {
                //$obj = file_get_contents_utf8(PROTOCOL . "://" . $tPath);
                $obj = easyAmazonWishlistCurlURL(PROTOCOL . "://" . $tPath);
                //$json_array = convertFromAmazon($seralized_object);
                $numRecords = easyAmazonWishlistGetNumRecords($obj);
                $obj = substr($obj, 36);
                $obj = strstr($obj, ", NumRecords", true);
                $obj = str_replace("ASIN", "\"ASIN\"", $obj);
                $obj = str_replace(" Title :", " \"Title\" :", $obj);
                $obj = str_replace(" Price :", " \"Price\" :", $obj);
                $obj = str_replace(" ImageUrl ", " \"ImageUrl\" ", $obj);
                $obj = str_replace("LargeImageUrl", "\"LargeImageUrl\"", $obj);
                $obj = str_replace(" ImageHeight ", " \"ImageHeight\" ", $obj);
                $obj = str_replace(" ImageWidth ", " \"ImageWidth\" ", $obj);
                $obj = str_replace("ListItemId", "\"ListItemId\"", $obj);
                $obj = str_replace(" Rating :", " \"Rating\" :", $obj);
                $obj = str_replace("TotalReviews", "\"TotalReviews\"", $obj);
                $obj = str_replace("Subtitle", " \"Subtitle\"", $obj);
                $obj = str_replace(" Comment :", " \"Comment\" :", $obj);
                $obj = str_replace("ThumbImageUrl", "\"ThumbImageUrl\"", $obj);
                $obj = str_replace("ThumbImageHeight", "\"ThumbImageHeight\"", $obj);
                $obj = str_replace("ThumbImageWidth", "\"ThumbImageWidth\"", $obj);
                $obj = str_replace(" category :", " \"category\" :", $obj);
                $obj = str_replace("DetailPageURL", "\"DetailPageURL\"", $obj);
                $wishlistArray = json_decode($obj);
                $itemsLeft = intval($numRecords) - 10;
                $itemCount = 10;
                $moreItems = array();
                $numItems = null;
                for ($l = $itemsLeft; $l > 0; $l = $l - $numItems) { //$numItems
                    if ($itemsLeft > 10) {
                        $numItems = 10;
                    } else {
                        $numItems = $itemsLeft;
                    }
                    $tPath = "ws." . $website . base64_decode("L3dpZGdldHMvcT9PcGVyYXRpb249R2V0UmVzdWx0cyZMaXN0SWQ9") . $wishlistId . "&multipageStart=" . $itemCount . "&InstanceId=0&multipageCount=" . $numItems . base64_decode("JlNvcnQ9RGF0ZUFkZGVkJlRlbXBsYXRlSWQ9ODAwNCZTZXJ2aWNlVmVyc2lvbj0yMDA3MDgyMiZNYXJrZXRQbGFjZT0=") . $locale;
                    $serialized_object = easyAmazonWishlistCurlURL(PROTOCOL . "://" . $tPath);
                    $serialized_object = substr($serialized_object, 36);
                    $serialized_object = strstr($serialized_object, ", NumRecords", true);
                    $serialized_object = str_replace("ASIN", "\"ASIN\"", $serialized_object);
                    $serialized_object = str_replace(" Title :", " \"Title\" :", $serialized_object);
                    $serialized_object = str_replace(" Price :", " \"Price\" :", $serialized_object);
                    $serialized_object = str_replace(" ImageUrl ", " \"ImageUrl\" ", $serialized_object);
                    $serialized_object = str_replace("LargeImageUrl", "\"LargeImageUrl\"", $serialized_object);
                    $serialized_object = str_replace(" ImageHeight ", " \"ImageHeight\" ", $serialized_object);
                    $serialized_object = str_replace(" ImageWidth ", " \"ImageWidth\" ", $serialized_object);
                    $serialized_object = str_replace("ListItemId", "\"ListItemId\"", $serialized_object);
                    $serialized_object = str_replace(" Rating :", " \"Rating\" :", $serialized_object);
                    $serialized_object = str_replace("TotalReviews", "\"TotalReviews\"", $serialized_object);
                    $serialized_object = str_replace("Subtitle", "\"Subtitle\"", $serialized_object);
                    $serialized_object = str_replace(" Comment :", " \"Comment\" :", $serialized_object);
                    $serialized_object = str_replace("ThumbImageUrl", "\"ThumbImageUrl\"", $serialized_object);
                    $serialized_object = str_replace("ThumbImageHeight", "\"ThumbImageHeight\"", $serialized_object);
                    $serialized_object = str_replace("ThumbImageWidth", "\"ThumbImageWidth\"", $serialized_object);
                    $serialized_object = str_replace(" category :", " \"category\" :", $serialized_object);
                    $serialized_object = str_replace("DetailPageURL", "\"DetailPageURL\"", $serialized_object);
                    $moreItems = json_decode($serialized_object);
                    $itemCount = $itemCount + $numItems;
                    $wishlistArray = array_merge($wishlistArray, $moreItems);
                }
                if (isset($wishlistArray)) {
                    foreach ($wishlistArray as $value) {
                        $value->DetailPageURL = $value->DetailPageURL . base64_decode("P2NvbGlkPTIwWVhETVVFN004QUQmbGlua0NvZGU9d3dsJnRhZz13d3d3ZWJtYXN0ZXJuLTIw");
                    }
                }
                $wishlist_json = json_encode($wishlistArray);
                file_put_contents(__DIR__ . 'easy-amazon-wishlist.cache.temp', $wishlist_json, LOCK_EX);
            } catch (Exception $o) {
                error_log($o);
            }
            ob_clean();
            echo $wishlist_json;
            die(); // this is required to return a proper result
        }
    }

    function eaw_search_action_callback() {
        global $wpdb; // this is how you get access to the database
        $contents = "[]";
        $search_val = isset($_POST['search_val']) && (strlen($_POST['search_val']) < 40) ? htmlspecialchars($_POST['search_val']) : null;
        $country = isset($_POST['country']) && (strlen($_POST['country']) < 40) ? htmlspecialchars($_POST['country']) : null;
        //check_ajax_referer(); add security on values passed (strip html, etc)
        if (isset($search_val) && isset($country)) {
            $localesArray = easy_amazon_wishlist_amazonLocales();
            $locale = $localesArray[$country];
            $websitesArray = easy_amazon_wishlist_amazonWebsites();
            $website = $websitesArray[$country];
            try {
                $validator = new EasyAmazonWishlistEmailAddressValidator;
                if ($validator->check_email_address($search_val)) {
                    $contents = getWishlists($website, $locale, 'Email', rawurlencode($search_val), '15', '0');
                }
                if ($contents == "[]") {
                    $contents = getWishlists($website, $locale, 'Name', rawurlencode($search_val), '15', '0');
                }
            } catch (Exception $o) {
                error_log($o);
            }
            ob_clean();
            echo $contents;
            die();
        }
    }

}

function easy_amazon_wishlist_admin_page() {

    if (is_admin() === true) {
    /*$easy_amazon_wishlist_show_text_link = get_option('easy-amazon-wishlist-show-text-link');
    $easy_amazon_wishlist_show_image = get_option('easy-amazon-wishlist-show-image');
    $easy_amazon_wishlist_show_price = get_option('easy-amazon-wishlist-show-price');
    $easy_amazon_wishlist_show_button = get_option('easy-amazon-wishlist-show-button');
    $easy_amazon_wishlist_button_text = get_option('easy-amazon-wishlist-button-text');
    $easy_amazon_wishlist_text_link_char_limit = get_option('easy-amazon-wishlist-text-link-char-limit');*/
        add_action('admin_footer', 'easy_amazon_wishlist_action_javascript');

        function easy_amazon_wishlist_action_javascript() {
        $wishlistArray = null;
            $cache_file = __DIR__ . 'easy-amazon-wishlist.cache';
            if (file_exists($cache_file)) {
                $wishlist_json = file_get_contents($cache_file);
                $wishlists = json_decode($wishlist_json);
                for ($i = 0; $i < count($wishlists); $i++) {
                    $wishlistArray[] = $wishlists[$i]->Title;
                }
            }
            ?>
            <script type="text/javascript" >

                jQuery(document).ready(function($) {

                var wishlistArray = <?php echo json_encode($wishlistArray); ?>;

                    function easyAmazonWishlistWriteWishlists(numTDs, numRows, wishlistCounter, numWishlists, wishlistArray){
                        var wishlistHTML = '<table border="1" width="100%">';
                        for (var i = 1; i <= numRows && wishlistCounter < numWishlists; i++) {
                            wishlistHTML = wishlistHTML + '<tr>';
                            for (var x = 1; x <= numTDs && wishlistCounter < numWishlists; x++) {

                                var wishlist = {
                                    amazonWishlistId: wishlistArray[wishlistCounter].ListId,
                                    totalWishlistItems: wishlistArray[wishlistCounter].TotalItems,
                                    amazonWishlistURL: wishlistArray[wishlistCounter].ListURL,
                                    amazonWishlistCustomerName: wishlistArray[wishlistCounter].CustomerName,
                                    amazonWishlistDateCreated: formatDate(new Date(getDateFromFormat(wishlistArray[wishlistCounter].DateCreated, 'yyyy-MM-dd')), 'MM/dd/y'),
                                    amazonWishlistTitle: wishlistArray[wishlistCounter].ListName,
                                    toString: function() {
                                        return '<td style="text-align:center;" width="200" title="List Name: ' + this.amazonWishlistTitle + ' Date Created:' + this.amazonWishlistDateCreated + ' Total Items:' + this.totalWishlistItems + ' (incl. deleted)" id="' + this.amazonWishlistId + '" class="wishlist">' + this.amazonWishlistCustomerName + '(' + this.amazonWishlistTitle + ')<button style="float:right;cursor:pointer;" id="' + this.amazonWishlistTitle + '" title="Choose ' + this.amazonWishlistTitle + ' Created:' + this.amazonWishlistDateCreated + '   Total(incl. deleted):' + this.totalWishlistItems + '" class="easy-amazon-wishlist-search-choose-button"><? esc_attr_e( 'Preview', 'EasyAmazonWishlist' ); ?></button></td>';
                                    }
                                }
                                wishlistHTML = wishlistHTML + wishlist.toString();
                                wishlistCounter++;
                            }
                            wishlistHTML = wishlistHTML + '</tr>';
                        }
                        wishlistHTML = wishlistHTML + '</table>';
                        return wishlistHTML;
                    }

                    function eawDisplayWishlistsFound(wishlistArray) {
                        if(wishlistArray){
                        var numWishlists = wishlistArray.length;
                        var numRows = 5;
                        var numTDs = Math.floor(numWishlists / numRows) + 1;
                        var wishlistHTML = '<table style="width:100%" id="easy-amazon-wishlist-results" border="0"><tr><th style="color:black;text-align:center;" scope="row" id="easy-amazon-wishlists-table-header"><? esc_attr_e( 'Wishlists Found', 'EasyAmazonWishlist' ); ?>: ' + wishlistArray[0].NumRecords + '<div style="float:right" id="pageNavPosition">' + easyAmazonWishlistPagination(wishlistArray[0].NumPages, wishlistArray[0].NumRecords) + '</div>' + '</th></tr><tr><td id="easy-amazon-wishlists-table">';
                        wishlistHTML = wishlistHTML + easyAmazonWishlistWriteWishlists(numTDs, numRows, 0, numWishlists, wishlistArray);
                        wishlistHTML = wishlistHTML + "</td></tr></table>";
                        } else {
                            wishlistHTML = '<table id="easy-amazon-wishlist-results" border="1"><tr><th style="color:black;text-align:center;" scope="row" id="easy-amazon-wishlists-table-header"><? esc_attr_e( 'Error processing wishlists', 'EasyAmazonWishlist' ); ?>...<div style="float:right" id="pageNavPosition"></div>' + '</th></tr></table>';
                        }
                        return wishlistHTML;
                    }

                    jQuery(document).on('click', '.easyAmazonWishlistPagination', function(e) {
                        e.preventDefault();
                        e.stopPropagation();
                        var thisNumString = $(this).attr('id');
                        var idArray = thisNumString.split('-');
                        var thisNum = idArray[1];
                        jQuery.ajax({
                            url: "<?php echo admin_url('admin-ajax.php'); ?>",
                            type: 'POST',
                            data: {
                                action: 'eaw_pagination_action',
                                numClicked: thisNum,
                                search_val: $('#easy-amazon-wishlist-search').val(),
                                country: $('#easy-amazon-wishlist-websites').val()
                            },
                            beforeSend: function() {
                                $('#easy-amazon-wishlists-table').fadeOut('slow');
                            },
                            success: function(myresult) {
                                var decodedObj = decodeURIComponent(escape(myresult));
                                var wishlistArray = jQuery.parseJSON(decodedObj);
                                var numWishlists = wishlistArray.length;
                                var numRows = 5;
                                var numTDs = Math.floor(numWishlists / numRows) + 1;
                                var wishlistHTML = easyAmazonWishlistWriteWishlists(numTDs, numRows, 0, numWishlists, wishlistArray);
                                $('#easy-amazon-wishlists-table').html(wishlistHTML).fadeIn('slow', function(){
                                   $('div.easyAmazonWishlistPagination').removeClass('current');
                                   $('#page-' + thisNum).addClass('current');
                                });
                            },
                            failure: function(myresult) {
                            }
                        });
                    });

                    function easyAmazonWishlistPagination(numPages) {
                        var pagination = "";
                        if (numPages > 20) {
                            numPages = 20;
                        }
                        for (var i = numPages; i > 0; i--) {
                            pagination = pagination + ' <div style="float:right;margin:5px;" class="easyAmazonWishlistPagination ';
                            if (i == 1) {
                                pagination = pagination + 'current';
                            }
                            pagination = pagination + '" id="page-' + i + '">' + i + '</div> ';
                        }
                        return pagination;
                    }

                    function previewWishlist(button, wishlistId, country) {
                        var text = button.text();
                        jQuery.ajax({
                            url: "<?php echo admin_url('admin-ajax.php'); ?>",
                            type: 'POST',
                            data: {
                                action: 'eaw_preview_action',
                                wishlistId: wishlistId,
                                country: country
                            },
                            beforeSend: function() {
                                $('#wishlistsPreview').html('<? esc_attr_e( 'Loading', 'EasyAmazonWishlist' ); ?>...');
                                button.text('');
                            },
                            success: function(myresult) {
                                var wishlistArray = jQuery.parseJSON(myresult);
                                easyAmazonWishlistDisplayPreviewWishlist(wishlistArray);
                                button.text(text);
                            },
                            failure: function(myresult) {
                                $('#wishlistsPreview').text("<p><? esc_attr_e( "Failed to load Wishlist.  Please verify that this is a valid Amazon Wishlist ID and that you have specified the correct country", 'EasyAmazonWishlist' ); ?>.</p>").html();
                                button.text(text);
                            }
                        });
                    }

                    function easyAmazonWishlistDisplayPreviewWishlist(wishlistArray) {
                        var wishlist = '<div id="easy-amazon-wishlist-list">';
                        if (typeof wishlistArray !== 'undefined' && wishlistArray !== null) {
                            for (var i = 0; i < wishlistArray.length; i++) {
                                wishlist = wishlist + '<div style="clear:both;padding-bottom:5px;overflow: auto;width: 100%"><div style="padding:3px;" class="easy-amazon-wishlist-title"><a href="' + wishlistArray[i].DetailPageURL + '" target="_blank">' + wishlistArray[i].Title + '</a></div><div><a class="easy-amazon-wishlist-image" href="' + wishlistArray[i].DetailPageURL + '" target="_blank"><img title="<? echo htmlentities(__( 'Buy me this on Amazon', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8"); ?>!" alt="' + wishlistArray[i].Title + '" style="float:left;padding:3px;" src="' + wishlistArray[i].ThumbImageUrl + '" width="' + wishlistArray[i].ThumbImageWidth + '" height="' + wishlistArray[i].ThumbImageHeight + '" /></a><span class="easy-amazon-wishlist-price">' + wishlistArray[i].Price + '</span><br /><a class="easy-amazon-wishlist-button" href="' + wishlistArray[i].DetailPageURL + '" target="_blank"><button class="button"><? esc_attr_e( 'More Info', 'EasyAmazonWishlist'); ?></button></a></div></div>';
                            }
                        } else {
                            wishlist = wishlist + '[EMPTY WISHLIST]';
                        }
                        wishlist = wishlist + '</div>';
                        $('#wishlistsPreview').html(wishlist).slideDown('slow');
                    }

                    jQuery(window).bind('beforeunload', function(e) {
                        e.stopPropagation();
                        if ($('#easy-amazon-wishlist-update').hasClass('easy-amazon-wishlist-modified')) {
                            e.returnValue = '<? esc_attr_e( 'You have unsaved changes. Click "update" to save your changes', 'EasyAmazonWishlist' ); ?>!';
                            return e.returnValue;
                        }
                    });

                    jQuery(document).on('change', '#easy-amazon-wishlist-show-text-link', function(e) {
                        /* easy-amazon-wishlist-title */
                        if(!jQuery('#easy-amazon-wishlist-show-text-link').prop('checked')){
                            jQuery('.easy-amazon-wishlist-title').hide();

                        } else {
                            jQuery('.easy-amazon-wishlist-title').show();
                        }
                        $('#easy-amazon-wishlist-update').addClass('easy-amazon-wishlist-modified');
                    });

                    jQuery(document).on('keyup', '#easy-amazon-wishlist-text-link-char-limit', function(e) {
                        if(parseInt(jQuery('#easy-amazon-wishlist-text-link-char-limit').val())){
                            jQuery('.easy-amazon-wishlist-title a').each(function(i) {
                                var substr = wishlistArray[i].substring(0, jQuery('#easy-amazon-wishlist-text-link-char-limit').val());
                                if (wishlistArray[i].length > substr.length) {substr = substr + '...';}
                                jQuery(this).text(substr );
                                //jQuery(this).text(jQuery(this).text().substring(0, jQuery(this).text()) );
                            });
                            $('#easy-amazon-wishlist-update').addClass('easy-amazon-wishlist-modified');
                        }
                    });

                    jQuery(document).on('keyup', '#easy-amazon-wishlist-button-text', function(e) {
                            jQuery('.easy-amazon-wishlist-button button').each(function(i) {
                                jQuery(this).text(jQuery('#easy-amazon-wishlist-button-text').val());
                            });
                            $('#easy-amazon-wishlist-update').addClass('easy-amazon-wishlist-modified');

                    });

                    jQuery(document).on('change', '#easy-amazon-wishlist-show-image', function(e) {
                        /* easy-amazon-wishlist-title */
                        if(!jQuery('#easy-amazon-wishlist-show-image').prop('checked')){
                            jQuery('.easy-amazon-wishlist-image').hide();

                        } else {
                            jQuery('.easy-amazon-wishlist-image').show();
                        }
                        $('#easy-amazon-wishlist-update').addClass('easy-amazon-wishlist-modified');
                    });
                    jQuery(document).on('change', '#easy-amazon-wishlist-show-price', function(e) {
                        if(!jQuery('#easy-amazon-wishlist-show-price').prop('checked')){
                            jQuery('.easy-amazon-wishlist-price').hide();

                        } else {
                            jQuery('.easy-amazon-wishlist-price').show();
                        }
                        $('#easy-amazon-wishlist-update').addClass('easy-amazon-wishlist-modified');
                    });
                    jQuery(document).on('change', '#easy-amazon-wishlist-show-button', function(e) {
                        /* easy-amazon-wishlist-title */
                        if(!jQuery('#easy-amazon-wishlist-show-button').prop('checked')){
                            jQuery('.easy-amazon-wishlist-button').hide();

                        } else {
                            jQuery('.easy-amazon-wishlist-button').show();
                        }
                        $('#easy-amazon-wishlist-update').addClass('easy-amazon-wishlist-modified');
                    });

                    jQuery(document).on('click', '#easy-amazon-wishlist-update', function(e) {
                        $('#easy-amazon-wishlist-update').removeClass('easy-amazon-wishlist-modified');
                    });

                    jQuery(document).on('click', '.easy-amazon-wishlist-search-choose-button', function(e) {
                        e.preventDefault();
                        e.stopPropagation();
                        var thisButton = $(this);
                        var wishlistId = $(this).parent().attr('id');
                        $('#easy-amazon-wishlist-listID').val(wishlistId);
                        previewWishlist(thisButton, wishlistId, $('#easy-amazon-wishlist-websites').val());
                        $('#easy-amazon-wishlist-update').addClass('easy-amazon-wishlist-modified');
                    });


                    jQuery(document).on('click', "#easy-amazon-wishlist-preview-button", function(e) {
                        e.preventDefault();
                        e.stopPropagation();
                        var thisButton = $(this);
                        previewWishlist(thisButton, $('#easy-amazon-wishlist-listID').val(), $('#easy-amazon-wishlist-websites').val());
                        $('#easy-amazon-wishlist-update').addClass('easy-amazon-wishlist-modified');
                    });

                    jQuery(document).on('click', "#easy-amazon-wishlist-search-button", function(e) {
                        e.preventDefault();
                        e.stopPropagation();
                        jQuery.ajax({
                            url: "<?php echo admin_url('admin-ajax.php'); ?>",
                            type: 'POST',
                            data: {
                                action: 'eaw_search_action',
                                search_val: $('#easy-amazon-wishlist-search').val(),
                                country: $('#easy-amazon-wishlist-websites').val()
                            },
                            beforeSend: function() {
                                $('#easy-amazon-wishlist-search-button-div').html('<? esc_attr_e( 'Searching', 'EasyAmazonWishlist' ); ?>...');
                                $('#easy-amazon-wishlists-found').html('');
                                $('#easy-amazon-wishlist-search-results').empty();
                            },
                            success: function(myresult) {
                                try {
                                    var decodedObj = decodeURIComponent(escape(myresult));
                                    var wishlistArray = jQuery.parseJSON(decodedObj);
                                    var wishlistHTML = eawDisplayWishlistsFound(wishlistArray);
                                    $('#easy-amazon-wishlist-results').html(wishlistHTML).fadeIn('slow');
                                } catch (e) {
                                    //console.log('Error encounted handling wishlist: ' + e);
                                }
                                $('#easy-amazon-wishlist-search-button-div').html('<button style="cursor:pointer;" id="easy-amazon-wishlist-search-button"><? esc_attr_e( 'Search', 'EasyAmazonWishlist' ); ?></button>');
                            },
                            failure: function(e) {
                                $('#easy-amazon-wishlist-search-button-div').html('<button style="cursor:pointer;" id="easy-amazon-wishlist-search-button"><? esc_attr_e( 'Search', 'EasyAmazonWishlist' ); ?></button>');
                                $('#easy-amazon-wishlists-found').html('<? esc_attr_e( 'Failed to find a list matching that criteria', 'EasyAmazonWishlist' ); ?>');
                            }
                        });
                    });

                    function LZ(e){return(e<0||e>9?"":"0")+e}function isDate(e,t){var n=getDateFromFormat(e,t);if(n==0){return false}return true}function compareDates(e,t,n,r){var i=getDateFromFormat(e,t);var s=getDateFromFormat(n,r);if(i==0||s==0){return-1}else if(i>s){return 1}return 0}function formatDate(e,t){t=t+"";var n="";var r=0;var i="";var s="";var o=e.getYear()+"";var u=e.getMonth()+1;var a=e.getDate();var f=e.getDay();var l=e.getHours();var c=e.getMinutes();var h=e.getSeconds();var p,d,v,m,g,y,b,w,E,S,x,l,T,N,C,k;var L=new Object;if(o.length<4){o=""+(o-0+1900)}L["y"]=""+o;L["yyyy"]=o;L["yy"]=o.substring(2,4);L["M"]=u;L["MM"]=LZ(u);L["MMM"]=MONTH_NAMES[u-1];L["NNN"]=MONTH_NAMES[u+11];L["d"]=a;L["dd"]=LZ(a);L["E"]=DAY_NAMES[f+7];L["EE"]=DAY_NAMES[f];L["H"]=l;L["HH"]=LZ(l);if(l==0){L["h"]=12}else if(l>12){L["h"]=l-12}else{L["h"]=l}L["hh"]=LZ(L["h"]);if(l>11){L["K"]=l-12}else{L["K"]=l}L["k"]=l+1;L["KK"]=LZ(L["K"]);L["kk"]=LZ(L["k"]);if(l>11){L["a"]="PM"}else{L["a"]="AM"}L["m"]=c;L["mm"]=LZ(c);L["s"]=h;L["ss"]=LZ(h);while(r<t.length){i=t.charAt(r);s="";while(t.charAt(r)==i&&r<t.length){s+=t.charAt(r++)}if(L[s]!=null){n=n+L[s]}else{n=n+s}}return n}function _isInteger(e){var t="1234567890";for(var n=0;n<e.length;n++){if(t.indexOf(e.charAt(n))==-1){return false}}return true}function _getInt(e,t,n,r){for(var i=r;i>=n;i--){var s=e.substring(t,t+i);if(s.length<n){return null}if(_isInteger(s)){return s}}return null}function getDateFromFormat(e,t){e=e+"";t=t+"";var n=0;var r=0;var i="";var s="";var o="";var u,a;var f=new Date;var l=f.getYear();var c=f.getMonth()+1;var h=1;var p=f.getHours();var d=f.getMinutes();var v=f.getSeconds();var m="";while(r<t.length){i=t.charAt(r);s="";while(t.charAt(r)==i&&r<t.length){s+=t.charAt(r++)}if(s=="yyyy"||s=="yy"||s=="y"){if(s=="yyyy"){u=4;a=4}if(s=="yy"){u=2;a=2}if(s=="y"){u=2;a=4}l=_getInt(e,n,u,a);if(l==null){return 0}n+=l.length;if(l.length==2){if(l>70){l=1900+(l-0)}else{l=2e3+(l-0)}}}else if(s=="MMM"||s=="NNN"){c=0;for(var g=0;g<MONTH_NAMES.length;g++){var y=MONTH_NAMES[g];if(e.substring(n,n+y.length).toLowerCase()==y.toLowerCase()){if(s=="MMM"||s=="NNN"&&g>11){c=g+1;if(c>12){c-=12}n+=y.length;break}}}if(c<1||c>12){return 0}}else if(s=="EE"||s=="E"){for(var g=0;g<DAY_NAMES.length;g++){var b=DAY_NAMES[g];if(e.substring(n,n+b.length).toLowerCase()==b.toLowerCase()){n+=b.length;break}}}else if(s=="MM"||s=="M"){c=_getInt(e,n,s.length,2);if(c==null||c<1||c>12){return 0}n+=c.length}else if(s=="dd"||s=="d"){h=_getInt(e,n,s.length,2);if(h==null||h<1||h>31){return 0}n+=h.length}else if(s=="hh"||s=="h"){p=_getInt(e,n,s.length,2);if(p==null||p<1||p>12){return 0}n+=p.length}else if(s=="HH"||s=="H"){p=_getInt(e,n,s.length,2);if(p==null||p<0||p>23){return 0}n+=p.length}else if(s=="KK"||s=="K"){p=_getInt(e,n,s.length,2);if(p==null||p<0||p>11){return 0}n+=p.length}else if(s=="kk"||s=="k"){p=_getInt(e,n,s.length,2);if(p==null||p<1||p>24){return 0}n+=p.length;p--}else if(s=="mm"||s=="m"){d=_getInt(e,n,s.length,2);if(d==null||d<0||d>59){return 0}n+=d.length}else if(s=="ss"||s=="s"){v=_getInt(e,n,s.length,2);if(v==null||v<0||v>59){return 0}n+=v.length}else if(s=="a"){if(e.substring(n,n+2).toLowerCase()=="am"){m="AM"}else if(e.substring(n,n+2).toLowerCase()=="pm"){m="PM"}else{return 0}n+=2}else{if(e.substring(n,n+s.length)!=s){return 0}else{n+=s.length}}}if(n!=e.length){return 0}if(c==2){if(l%4==0&&l%100!=0||l%400==0){if(h>29){return 0}}else{if(h>28){return 0}}}if(c==4||c==6||c==9||c==11){if(h>30){return 0}}if(p<12&&m=="PM"){p=p-0+12}else if(p>11&&m=="AM"){p-=12}var w=new Date(l,c-1,h,p,d,v);return w.getTime()}function parseDate(e){var t=arguments.length==2?arguments[1]:false;generalFormats=new Array("y-M-d","MMM d, y","MMM d,y","y-MMM-d","d-MMM-y","MMM d");monthFirst=new Array("M/d/y","M-d-y","M.d.y","MMM-d","M/d","M-d");dateFirst=new Array("d/M/y","d-M-y","d.M.y","d-MMM","d/M","d-M");var n=new Array("generalFormats",t?"dateFirst":"monthFirst",t?"monthFirst":"dateFirst");var r=null;for(var i=0;i<n.length;i++){var s=window[n[i]];for(var o=0;o<s.length;o++){r=getDateFromFormat(e,s[o]);if(r!=0){return new Date(r)}}}return null}var MONTH_NAMES=new Array("January","February","March","April","May","June","July","August","September","October","November","December","Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec");var DAY_NAMES=new Array("Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sun","Mon","Tue","Wed","Thu","Fri","Sat");

    });
            </script>
                        <?php
                    }

                $html = <<<EOHTML
<style type="text/css">
.easyAmazonWishlistPagination {font-weight:bold;text-decoration:underline;cursor:pointer;}
.easyAmazonWishlistPagination:hover {font-weight:normal;}
.easyAmazonWishlistPagination.current {text-decoration:none;font-weight:normal;}
.easy-amazon-wishlist-modified {display: inline-block; position: relative; height: 33px; line-height: 33px; padding: 0 15px; font-size: 15px; color: white !important; text-decoration: none !important; text-shadow: 0 -1px rgba(0, 0, 0, 0.3);border: 2px solid;border-radius: 7px;outline: 0;-webkit-box-shadow: 0 2px 1px rgba(0, 0, 0, 0.25);box-shadow: 0 2px 1px rgba(0, 0, 0, 0.25);background: #d02e17;border-color: #942110 #902010 #741a0d;background-image: -webkit-linear-gradient(top, #e74a29 0%, #e6451b 50%, #d02e17 50%, #b3150b 100%);background-image: -moz-linear-gradient(top, #e74a29 0%, #e6451b 50%, #d02e17 50%, #b3150b 100%);background-image: -o-linear-gradient(top, #e74a29 0%, #e6451b 50%, #d02e17 50%, #b3150b 100%);background-image: linear-gradient(to bottom, #e74a29 0%, #e6451b 50%, #d02e17 50%, #b3150b 100%);}
.easy-amazon-wishlist-modified:active {background: black;background-image: -webkit-linear-gradient(top, #a9110b 0%, #de3819 60%, #e63b1b 100%);background-image: -moz-linear-gradient(top, #a9110b 0%, #de3819 60%, #e63b1b 100%);background-image: -o-linear-gradient(top, #a9110b 0%, #de3819 60%, #e63b1b 100%);background-image: linear-gradient(to bottom, #a9110b 0%, #de3819 60%, #e63b1b 100%);}
.easy-amazon-wishlist-modified:hover {color:black !important;}
.easy-amazon-wishlist-price {padding:3px;font-size: 12px;color: #3f3c39;font-weight: bold;margin:5px;}
.easy-amazon-wishlist-button {cursor:pointer;margin:5px;}
EOHTML;
	if(get_option('easy-amazon-wishlist-show-text-link') != 1)
		$html .= '.easy-amazon-wishlist-title{display:none;}" ';
	if(get_option('easy-amazon-wishlist-show-image') != 1)
		$html .= '.easy-amazon-wishlist-image{display:none;}" ';
	if(get_option('easy-amazon-wishlist-show-price') != 1)
		$html .= '.easy-amazon-wishlist-price{display:none;}" ';
	if(get_option('easy-amazon-wishlist-show-button') != 1)
		$html .= '.easy-amazon-wishlist-button{display:none;}" ';
	$html .= <<<EOHTML
</style>
<div>
<h2>
EOHTML;
    $html .= htmlentities(__( 'Easy Amazon Wishlist', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") .  ' - ' . htmlentities(__( 'Options', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
</h2>
<h3>
EOHTML;
    $html .= htmlentities(__( 'Instructions', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
</h3>
<p>
EOHTML;
    $html .= htmlentities(__( 'Update the Amazon website country', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") .  ' (amazon.com ' . htmlentities(__( 'for', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") . ' US,  amazon.co.uk ' . htmlentities(__( 'for', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") . ' England, ' . htmlentities(__( 'etc', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") . '.), ' . htmlentities(__( 'find the wishlist ID', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") . ', ' . htmlentities(__( 'or add it in directly if you already know it', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") . ' (' . htmlentities(__( 'and click', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") .  '"' . htmlentities(__( 'update', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") . '"), ' . htmlentities(__( 'and make sure to activate the', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") . ' <strong>' . htmlentities(__( 'Easy Amazon Wishlist', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8") . '</strong> ' . htmlentities(__( 'plugin and place the widget in your page', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
.</p>
<form method="post" action="options.php">
EOHTML;
                $html .= wp_nonce_field('update-options');
                $html .= <<<EOHTML

<table width="100%" border="0" class="form-table">
<tr valign="top">
        <th>
EOHTML;
                $html .=   htmlentities(__('Specify Amazon Website', 'EasyAmazonWishlist'), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
:</th>
        <td width="200">
		<select name="easy-amazon-wishlist-websites" id="easy-amazon-wishlist-websites">
EOHTML;
                foreach (easy_amazon_wishlist_amazonWebsites() as $key => $title) {
                    $selected = '';
                    if (get_option('easy-amazon-wishlist-websites') == $key)
                        $selected = 'selected="selected"';
                    $html .= '<option value="' . $key . '" ' . $selected . '>' . $title . '</option>';
                }
                $html .= <<<EOHTML

        </td><td style="width:100%" rowspan="13" valign="top" id="easy-amazon-wishlist-results"></td><td rowspan="13">
<h3>
EOHTML;
               $html .= htmlentities(__( 'Your Wishlist Preview', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8");
               $html .= <<<EOHTML
</h3>
<table border="0" width="300" style="border-collapse:collapse">
	<tr>
		<td id="wishlistsPreview">
EOHTML;
                $html .= easy_amazon_wishlist();
                $html .= <<<EOHTML
</td>
	</tr>
</table></td>
</tr>
<tr>
    <th valign="top">
EOHTML;
                 $html .= htmlentities(__( 'Find the', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . ' ' .  htmlentities(__( 'Amazon Wishlist', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . ' ' . htmlentities(__( 'to import by providing either', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . '<br />' . htmlentities(__( 'the', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . ' <span style="font-weight:bold;">' . htmlentities(__( 'Email Address', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . '</span> ' . htmlentities(__( 'or', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . ' <span style="font-weight:bold;">' . htmlentities(__( 'Name', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . '</span> ' . htmlentities(__( 'of the owner of the Wishlist', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . ':</th>
<td valign="top"><input name="easy-amazon-wishlist-search" type="text" id="easy-amazon-wishlist-search" value="" /><div id="easy-amazon-wishlist-search-button-div"><button style="cursor:pointer;" id="easy-amazon-wishlist-search-button">' . htmlentities(__( 'Search', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
</button></div></td>
</tr>
<tr><th style="font-weight:bold;">
EOHTML;
                $html .= htmlentities(__( 'OR', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
</th><td></td></tr>
<tr>
<th scope="row">
EOHTML;
                $html .= htmlentities(__( 'If you already know the', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . ' <strong>' . htmlentities(__( 'Amazon Wishlist ID', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
</strong>:</th>
<td><input name="easy-amazon-wishlist-listID" type="text" id="easy-amazon-wishlist-listID" value="
EOHTML;
                $html .= get_option('easy-amazon-wishlist-listID');
                $html .= <<<EOHTML
" /><div id="easy-amazon-wishlist-preview-button-div"><button style="cursor:pointer;" id="easy-amazon-wishlist-preview-button">
EOHTML;
                $html .= htmlentities(__( 'Preview Wishlist', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
</button></div></td>
</tr>
<tr><td colspan="2" valign="top">
<input type="hidden" name="action" value="update" />
<input type="hidden" name="page_options" value="easy-amazon-wishlist-search, easy-amazon-wishlist-listID, easy-amazon-wishlist-websites, easy-amazon-wishlist-show-text-link, easy-amazon-wishlist-show-image, easy-amazon-wishlist-show-price, easy-amazon-wishlist-show-button, easy-amazon-wishlist-button-text, easy-amazon-wishlist-text-link-char-limit" />
<h3>Display Settings</h3></td></tr>
<tr><td>Show Text Link</td><td><input
EOHTML;
	if(get_option('easy-amazon-wishlist-show-text-link') == 1)
		$html .= ' checked="checked" ';
	$html .= <<<EOHTML
 type="checkbox" id="easy-amazon-wishlist-show-text-link" name="easy-amazon-wishlist-show-text-link" value="1"  /></td></tr>
<tr><td>Set Char Limit on Link</td><td><input type="text" id="easy-amazon-wishlist-text-link-char-limit" name="easy-amazon-wishlist-text-link-char-limit" value="
EOHTML;
                $html .= get_option('easy-amazon-wishlist-text-link-char-limit');
	$html .= <<<EOHTML
"  /></td></tr>
<tr><td>Show Image</td><td><input
EOHTML;
	if(get_option('easy-amazon-wishlist-show-image') == 1)
		$html .= ' checked="checked" ';
	$html .= <<<EOHTML
 type="checkbox" id="easy-amazon-wishlist-show-image" name="easy-amazon-wishlist-show-image" value="1"  /></td></tr>
<tr><td>Show Price</td><td><input
EOHTML;
	if(get_option('easy-amazon-wishlist-show-price') == 1)
		$html .= ' checked="checked" ';
	$html .= <<<EOHTML
 type="checkbox" id="easy-amazon-wishlist-show-price" name="easy-amazon-wishlist-show-price" value="1"  /></td></tr>
<tr><td>Show Button</td><td><input
EOHTML;
	if(get_option('easy-amazon-wishlist-show-button') == 1)
		$html .= ' checked="checked" ';
	$html .= <<<EOHTML
 type="checkbox" id="easy-amazon-wishlist-show-button" name="easy-amazon-wishlist-show-button" value="1"  /></td></tr>
<tr><td>Button Text</td><td><input type="text" id="easy-amazon-wishlist-button-text" name="easy-amazon-wishlist-button-text" value="
EOHTML;
                $html .= get_option('easy-amazon-wishlist-button-text');
	$html .= <<<EOHTML
"  /></td></tr>
EOHTML;
                $html .= get_option('easy-amazon-wishlist-button-text');
	$html .= <<<EOHTML
<tr><td colspan="2">
<p style="width:250px;margin-left:auto;margin-right:auto;">
<input id="easy-amazon-wishlist-update" class="easy_amazon_wishlist_submit_button" style="cursor:pointer;" name="update" type="submit" value="
EOHTML;
                $html .= htmlentities(__( 'Update', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
" /> (
EOHTML;
                $html .= htmlentities(__( 'saves your changes', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8");
                $html .= <<<EOHTML
)</p></td></tr></table>
</form>
</div>
EOHTML;
                echo $html;
            }
}
            register_activation_hook(__FILE__, 'easy_amazon_wishlist_install');
            register_deactivation_hook(__FILE__, 'easy_amazon_wishlist_remove');

            function easy_amazon_wishlist_install() {
                add_option("easy-amazon-wishlist-listID", '', '', 'yes');
                //add_option("easy-amazon-wishlist-layout", $default, '', 'yes');
                add_option("easy-amazon-wishlist-websites", 'com', '', 'yes');
                //add_option("easy-amazon-wishlist-use-unsorted-list", '1', '', 'yes');
                add_option("easy-amazon-wishlist-show-text-link", '1', '', 'yes');
                add_option("easy-amazon-wishlist-show-image", '1', '', 'yes');
                add_option("easy-amazon-wishlist-show-price", '1', '', 'yes');
                add_option("easy-amazon-wishlist-show-button", '1', '', 'yes');
                add_option("easy-amazon-wishlist-button-text", htmlentities(__( 'More Info', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8"), '', 'yes');
                add_option("easy-amazon-wishlist-text-link-char-limit", '', '', 'yes');
            }

            function easy_amazon_wishlist_remove() {
                delete_option('easy-amazon-wishlist-listID');
                delete_option('easy-amazon-wishlist-websites');
                //delete_option('easy-amazon-wishlist-use-unsorted-list');
                delete_option('easy-amazon-wishlist-show-text-link');
                delete_option('easy-amazon-wishlist-show-image');
                delete_option('easy-amazon-wishlist-show-price');
                delete_option('easy-amazon-wishlist-show-button');
                delete_option('easy-amazon-wishlist-button-text');
                delete_option('easy-amazon-wishlist-text-link-char-limit');
            }

            class Easy_Amazon_Wishlist_Widget extends WP_Widget {

                function Easy_Amazon_Wishlist_Widget() {
                    parent::WP_Widget(false, $name = 'Easy Amazon Wishlist Widget');
                }

                function widget($args, $instance) {
                    extract($args);
                    $title = apply_filters('widget_title', $instance['title']);
                    echo $before_widget;
                    if ($title) {
                        echo $before_title . $title . $after_title;
                    }
                    ?>
                    <div class="my_textbox">
                        <?php echo easy_amazon_wishlist(); ?>
                    </div>
                    <?php
                    echo $after_widget;
                }

                function update($new_instance, $old_instance) {
                    $instance = $old_instance;
                    $instance['title'] = strip_tags($new_instance['title']);
                    return $instance;
                }

                function form($instance) {
                    //Set up some default widget settings.
                    $defaults = array('title' => htmlentities(__('My Amazon Wishlist', 'My Amazon Wishlist'), ENT_QUOTES, "UTF-8"));
                    $instance = wp_parse_args((array) $instance, $defaults);

                    //Widget Title: Text Input.
                    ?>
                    <p>
                        <label for="<?php echo $this->get_field_id('title'); ?>"><?php htmlentities(_e('Title', 'My Amazon Wishlist'), ENT_QUOTES, "UTF-8"); ?>:</label>
                        <input id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $instance['title']; ?>" style="text-align:center;width:100%;" />
                    </p>
                    <?php
                }

            }

            add_action('widgets_init', 'register_Easy_Amazon_Wishlist_Widget');

            function register_Easy_Amazon_Wishlist_Widget() {
                register_widget('Easy_Amazon_Wishlist_Widget');
            }
//TODO encapsalate
//REQUIRED CLASSES AND FUNCTIONS
            class EasyAmazonWishlistEmailAddressValidator {

                public function check_email_address($strEmailAddress) {
                    if (preg_match('/[\x00-\x1F\x7F-\xFF]/', $strEmailAddress)) {
                        return false;
                    }
                    if (!$this->check_text_length($strEmailAddress, 3, 256)) {
                        return false;
                    }
                    $intAtSymbol = strrpos($strEmailAddress, '@');
                    if ($intAtSymbol === false) {
                        return false;
                    }
                    $arrEmailAddress[0] = substr($strEmailAddress, 0, $intAtSymbol);
                    $arrEmailAddress[1] = substr($strEmailAddress, $intAtSymbol + 1);
                    $arrTempAddress[0] = preg_replace('/\./'
                            , ''
                            , $arrEmailAddress[0]);
                    $arrTempAddress[0] = preg_replace('/"[^"]+"/'
                            , ''
                            , $arrTempAddress[0]);
                    $arrTempAddress[1] = $arrEmailAddress[1];
                    $strTempAddress = $arrTempAddress[0] . $arrTempAddress[1];
                    if (strrpos($strTempAddress, '@') !== false) {
                        return false;
                    }
                    if (!$this->check_local_portion($arrEmailAddress[0])) {
                        return false;
                    }
                    if (!$this->check_domain_portion($arrEmailAddress[1])) {
                        return false;
                    }
                    return true;
                }

                protected function check_local_portion($strLocalPortion) {
                    if (!$this->check_text_length($strLocalPortion, 1, 64)) {
                        return false;
                    }
                    $arrLocalPortion = explode('.', $strLocalPortion);
                    for ($i = 0, $max = sizeof($arrLocalPortion); $i < $max; $i++) {
                        if (!preg_match('.^('
                                        . '([A-Za-z0-9!#$%&\'*+/=?^_`{|}~-]'
                                        . '[A-Za-z0-9!#$%&\'*+/=?^_`{|}~-]{0,63})'
                                        . '|'
                                        . '("[^\\\"]{0,62}")'
                                        . ')$.'
                                        , $arrLocalPortion[$i])) {
                            return false;
                        }
                    }
                    return true;
                }

                protected function check_domain_portion($strDomainPortion) {
                    if (!$this->check_text_length($strDomainPortion, 1, 255)) {
                        return false;
                    }
                    if (preg_match('/^(25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])'
                                    . '(\.(25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])){3}$/'
                                    , $strDomainPortion) ||
                            preg_match('/^\[(25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])'
                                    . '(\.(25[0-5]|2[0-4][0-9]|1[0-9][0-9]|[1-9]?[0-9])){3}\]$/'
                                    , $strDomainPortion)) {
                        return true;
                    } else {
                        $arrDomainPortion = explode('.', $strDomainPortion);
                        if (sizeof($arrDomainPortion) < 2) {
                            return false;
                        }
                        for ($i = 0, $max = sizeof($arrDomainPortion); $i < $max; $i++) {
                            if (!$this->check_text_length($arrDomainPortion[$i], 1, 63)) {
                                return false;
                            }
                            if (!preg_match('/^(([A-Za-z0-9][A-Za-z0-9-]{0,61}[A-Za-z0-9])|'
                                            . '([A-Za-z0-9]+))$/', $arrDomainPortion[$i])) {
                                return false;
                            }
                            if ($i == $max - 1) {
                                if (strlen(preg_replace('/[0-9]/', '', $arrDomainPortion[$i])) <= 0) {
                                    return false;
                                }
                            }
                        }
                    }
                    return true;
                }

                protected function check_text_length($strText, $intMinimum, $intMaximum) {
                    // Minimum and maximum are both inclusive
                    $intTextLength = strlen($strText);
                    if (($intTextLength < $intMinimum) || ($intTextLength > $intMaximum)) {
                        return false;
                    } else {
                        return true;
                    }
                }

            }

            function easyAmazonWishlistCurlURL($url) {
                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, $url);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
                $response = curl_exec($ch);
                return $response;
            }

            function easyAmazonWishlistGetNumRecords($obj) {
                $numItems = strstr($obj, ', NumRecords : "', false);
                $numItems = substr($numItems, 16);
                $numItems = strstr($numItems, '", MarketPlace', true);
                return intval($numItems);
            }

            function easyAmazonWishlistDisplayPreviewWishlist($wishlistArray, $show_text_link, $show_image, $show_price, $show_button, $button_text, $text_link_char_limit) {
                $wishlistHtml = '<div style="padding-bottom:5px;" id="easy-amazon-wishlist-list">';
                for ($i = 0; $i < count($wishlistArray); $i++) {
                    $wishlistHtml = $wishlistHtml . '<div style="clear:both;padding-bottom:5px;overflow: auto;width: 100%"><div style="';
                    if(!$show_text_link){$wishlistHtml = $wishlistHtml . 'display:none;';}
                    $wishlistHtml = $wishlistHtml . 'padding:3px;" class="easy-amazon-wishlist-title"><a href="' . $wishlistArray[$i]->DetailPageURL . '" target="_blank">';
                    if(isset($text_link_char_limit) && intval($text_link_char_limit)){
                        $substr = substr($wishlistArray[$i]->Title, 0, intval($text_link_char_limit));
                        if (strlen($substr) < strlen($wishlistArray[$i]->Title)) {$substr = $substr . '...';}
                        $wishlistHtml = $wishlistHtml . $substr;
                    }
                    else {$wishlistHtml = $wishlistHtml . $wishlistArray[$i]->Title;}
                    $wishlistHtml = $wishlistHtml . '</a></div><div><a style="';
                    if(!$show_image){$wishlistHtml = $wishlistHtml . 'display:none;';}
                    $wishlistHtml = $wishlistHtml . '" class="easy-amazon-wishlist-image" href="' . $wishlistArray[$i]->DetailPageURL . '" target="_blank"><img title="' . htmlentities(__( 'Buy me this on Amazon', 'EasyAmazonWishlist' ), ENT_QUOTES, "UTF-8") . '!" alt="' . $wishlistArray[$i]->Title . '" style="float:left;padding:3px;" src="' . $wishlistArray[$i]->ThumbImageUrl . '" width="' . $wishlistArray[$i]->ThumbImageWidth . '" height="' . $wishlistArray[$i]->ThumbImageHeight . '" /></a><span class="easy-amazon-wishlist-price" style="';
                    if(!$show_price){$wishlistHtml = $wishlistHtml . 'display:none;';}
                    $wishlistHtml = $wishlistHtml . 'padding:3px;font-size: 12px;color: #3f3c39;font-weight: bold;margin:5px;">' . $wishlistArray[$i]->Price . '</span><br /><a style="';
                    if(!$show_button){$wishlistHtml = $wishlistHtml . 'display:none;';}
                    $wishlistHtml = $wishlistHtml . '" class="easy-amazon-wishlist-button" href="' . $wishlistArray[$i]->DetailPageURL . '" target="_blank"><button class="button" style="cursor:pointer;margin:5px;">' . $button_text . '</button></a></div></div>';
                }
                $wishlistHtml = $wishlistHtml . '</div>';
                return $wishlistHtml;
            }

            function easy_amazon_wishlist_amazonWebsites() {
                $websites = array(
                    'com' => 'amazon.com',
                    'co.uk' => 'amazon.co.uk',
                    'de' => 'amazon.de',
                    'at' => 'amazon.at',
                    'fr' => 'amazon.fr',
                    'co.jp' => 'amazon.co.jp',
                    'ca' => 'amazon.ca',
                    'es' => 'amazon.es',
                    'cn' => 'amazon.cn',
                    'it' => 'amazon.it',
                );

                return $websites;
            }

            function easy_amazon_wishlist_amazonLocales() {
                $locales = array(
                    'com' => 'US',
                    'co.uk' => 'GB',
                    'de' => 'DE',
                    'at' => 'AT',
                    'fr' => 'FR',
                    'co.jp' => 'JP',
                    'ca' => 'CA',
                    'es' => 'ES',
                    'cn' => 'CN',
                    'it' => 'IT',
                );

                return $locales;
            }

            function getWishlists($website, $locale, $searchType, $searchKeywords, $wishlistCount, $pageCount) {
                $contents = "";
//https://widgets.amazon.com/xml?MarketPlace=US&Name=allison%20collins&multipageCount=15&multipageStart=15&Service=wishlistsearch
                $url = "https://widgets." . $website . "/xml?MarketPlace=" . $locale . "&" . $searchType . "=" . $searchKeywords . "&multipageCount=" . $wishlistCount . "&multipageStart=" . $pageCount . "&Service=wishlistsearch";
                $contents = file_get_contents($url);
                $contents = utf8_encode($contents);
                return $contents;
            }